\name{SMART}
\alias{SMART}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Scalable Multiple Annotation integration for trait-Relevant Tissue identification
}
\description{
This is an extension of the commonly used linear mixed model in order to jointly model multiple annotations with GWAS summary statistics to facilitate the identification of trait-relevant tissues. Generalized estimating equation (GEE) algorithm is applied for parameter inference.
}
\usage{
SMART(gss, sma, LD.dir, ma.scale = T, method = "Sandwich")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
\item{gss}{GWAS summary statistics with column names: SNP CHR N Z.
}
\item{sma}{Multiple annotations with column names: SNP CHR ann1 ann2 ann3 ...
}
\item{LD.dir}{Directory where saves the reference LD sparse matrix, which can be separated into different chromosomes or blocks.
}
\item{ma.scale}{When True, the multipe annotations will be standardized with mean 0 and variance. The first estimate will be the Vg (or heritabity).
}
\item{method}{There are two options. The default is "Sandwich", which consider the correlation between the summary statistics. The "Jackknife" method was applied in LDSC, the genome is divided into 200 blocks.
}
}
\details{
We consider a simple extension of the linear mixed model to evaluate jointly the contribution of multiple SNP annotations. To do so, we first consider the following multiple linear regression model that relates genotypes to phenotypes
y=Xβ+ϵ,            ϵ_i∼N(0,σ_e^2 ),
where y is an n-vector of phenotypes; X is an n by m matrix of genotypes; β is an m-vector of effect sizes; and ϵ is an n-vector of residual errors; each element ϵ_i is independent and identically distributed from a normal distribution with variance σ_e^2. We center the phenotype y and standardize each column of the genotype matrix X to have zero mean and unit variance, allowing us to ignore the intercept in the model.

Because p≫n, we have to make further modeling assumptions on the SNP effect sizes β to make the model identifiable. We do so by incorporating SNP annotation information and making the effect size β_j of j-th SNP depending on its annotations. Specifically, we assume that all SNPs are characterized by a same set of c annotations. For the j-th SNP, we denote A_j=(1,C_j1,C_j2,⋯,C_jc )^T as a (c+1)-vector of realized annotation values including a value of one that represents the intercept. These annotations can be either discrete or continuous. For example, one annotation could be a binary indicator on whether the SNP resides in exonic regions, while another annotation could be a continuous value of the CADD score of the SNP. To simplify presentation, we assemble the annotation vectors across all SNPs into an m by (c+1) annotation matrix A, where each row contains the annotation vector for the corresponding SNP.

We assume that the annotations for a given SNP influence its effect size. In particular, we assume that each effect size β_j is independent and follows a normal distribution with mean zero and a variance σ_j^2 that is SNP specific. The SNP-specific variance assumption generalizes the standard LMM assumption where every SNP is assumed to share a common variance. We further impose an extra layer of hierarchy by assuming that the SNP specific variance is a function of the annotation vector, or
β_j∼N(0,(σ_j^2)⁄m),        σ_j^2=A_j  α^*,
where α^*= (α_0¦α) is a (c+1)-vector of coefficients that include an intercept α_0 and a c-vector of annotation coefficients α. Each annotation coefficient is large when the corresponding annotation is predictive of the SNP effect size. Therefore, the annotation coefficients can be used to evaluate the importance of annotations. Above, we center the 2nd to the (c+1)-th columns of A_j to have mean zero across SNPs. After centering, the ratio α_0/(α_0+σ_e^2) has the natural interpretation of SNP heritability. Note that the assumed linear relationship between the SNP specific variance and annotations also naturally extends the modeling assumptions made in LDSC and MQS, both of which incorporate a single binary annotation . In addition, our polygenic modeling assumption complements alternative approaches in using sparse models for integrating functional annotations.

}
\value{
\item{theta.est}{The estimate of theta: Vg, annotation effect size, Vp}
\item{theta.se}{The standard error of the estimate of theta}
\item{theta.cov}{The covariance of the estimate of theta}
\item{TRD.Wald}{The Wald statistics to determine the trait-tissue relevance}
}
\references{
Incorporating Multiple Functional Annotations to Infer Trait-Relevant Tissues in Genome-wide Association Studies
}
\author{

}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}

\examples{
## Download some example data from http://www.xzlab.org/software.html
## In the example data, we provide ten tissue group specific annotations with four histione marks (H3K27me3, H3K36me3, H3K4me1 and H3K4me3) inside for 49081 SNPs on CHR 1; and the corresponding reference genotype of 503 EUR individuals for 1000 genome project.


setwd("C:/Users/xingjie hao/Desktop/SMART_example")
libarary(Matrix)
library(data.table)


## load reference genotype, we can direcly use the PLINK format
chr_index <- 1
gmat <- fread(paste("C:/Users/xingjie hao/Desktop/SMART_example/Ref1K/gtype/ref1k_chr_", chr_index, ".raw", sep = ""), header = T)
gmap <- fread(paste("C:/Users/xingjie hao/Desktop/SMART_example/Ref1K/gtype/ref1k_chr_", chr_index, ".bim", sep = ""), header = F)
gmat <- as.data.frame(gmat)
gmat <- gmat[, -c(1:6)]
gmat <- as.matrix(gmat)
gmat <- scale(gmat)
gmat <- unname(gmat)
gmap <- as.data.frame(gmap)[, 1:4]
colnames(gmap) <- c("CHR", "SNP", "cM", "BP")


## Compute the LD Sparse Matrix
ldmat_band <- LDSM(geno.x = gmat, geno.map = gmap, ld.mode = "gcm_band", win.size = 1, refld.bed = NULL)
R.mat <- ldmat_band$Rmat
## Save the LD Sparse Matrix
save(R.mat, file = paste("C:/Users/xingjie hao/Desktop/SMART_example/Ref1K/LDmat/ldsmat_", chr_index, ".RData", sep = ""))



## The name of the ten tissue group specific annotations
tissue_name <- c("Adipose", "AdrenalPancreas", "BloodImmune", "BoneConnective", "Cardiovascular", "CNS", "Gastrointestinal", "Liver", "Muscle", "Other")


## GWAS summary statistics example
sumstat_dat <- read.table("C:/Users/xingjie hao/Desktop/SMART_example/GSS/CD.gss", header = T)
head(sumstat_dat)

## Multiple annotations example
tissue_index <- 1
ann <- read.table(paste("C:/Users/xingjie hao/Desktop/SMART_example/SMA/", tissue_name[tissue_index], ".sma", sep = ""), header = T)
head(ann)


## Directory where saves the reference LD sparse matrix
ldsm.save.dir <- "C:/Users/xingjie hao/Desktop/SMART_example/Ref1K/LDmat/"


## Vector to same the TRD Wald statistics
TDR_vec <- rep(NA, 10)
names(TDR_vec) <- tissue_name

for(tissue_index in 1:10) {
  #tissue_index <- 1
  ann <- read.table(paste("C:/Users/xingjie hao/Desktop/SMART_example/SMA/", tissue_name[tissue_index], ".sma", sep = ""), header = T)
  smart_est <- SMART(gss = sumstat_dat, sma = ann, LD.dir = ldsm.save.dir, ma.scale = T, method = "Sandwich")
  TDR_vec[tissue_index] <- smart_est$TRD.Wald
}

TDR_vec


# Trait-Relevant Tissue Classification with EM
EM_pp <- EMmix(Zsq = TDR_vec, df.zsq = 4, beta.mean = 0.1, iter.max = 100, iter.limit = 0.001, NCP.diff.limit = NULL)
EM_pp$PP
}


